"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FiredevBinaryFileBackend = void 0;
var tslib_1 = require("tslib");
//#region imports
var tnp_core_1 = require("tnp-core");
var tnp_1 = require("tnp");
var tnp_config_1 = require("tnp-config");
var axios_1 = require("axios");
/* */
/* */
//#region @backend
var tnp_core_2 = require("tnp-core");
//#endregion
//#endregion
//#region constants
var environment = {};
//#region @backend
// @ts-ignore
environment = global['ENV'];
//#endregion
/* */
/* */
/* */
/* */
/* */
/* */
/* */
/* */
/* */
/* */
/* */
/* */
//#endregion
//#region description
/**
 * Backend (websql also) methods for FiredevBinaryFile
 *
 * + use entites injected controllers to access other backends
 * + don't use controllers methods/properties here
 */
//#endregion
var FiredevBinaryFileBackend = /** @class */ (function () {
    function FiredevBinaryFileBackend(ctrl) {
        //#region @backend
        this.ctrl = ctrl;
        this.project = tnp_1.Project.ins.nearestTo(process.cwd());
        console.log({
            'CWD': process.cwd(),
            nearestTo: this.project.genericName
        });
        this.assetsPath = this.project.location;
        //#endregion
    }
    //#endregion
    FiredevBinaryFileBackend.for = function (ctrl) { return new FiredevBinaryFileBackend(ctrl); };
    Object.defineProperty(FiredevBinaryFileBackend.prototype, "repo", {
        get: function () {
            return this.ctrl.repository;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FiredevBinaryFileBackend.prototype, "repository", {
        get: function () {
            return this.ctrl.repository;
        },
        enumerable: false,
        configurable: true
    });
    //#endregion
    //#region public methods / get by url
    //#region @websql
    FiredevBinaryFileBackend.prototype.getByUrl = function (relativePathOnServer) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var model;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.repository.findOne({
                            where: {
                                src: relativePathOnServer,
                            }
                        })];
                    case 1:
                        model = _a.sent();
                        return [2 /*return*/, model];
                }
            });
        });
    };
    //#endregion
    //#endregion
    //#region public methods / count entities
    //#region @websql
    FiredevBinaryFileBackend.prototype.countEntities = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.ctrl.repository.count()];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    //#endregion
    //#endregion
    //#region public methods / save file in nodejs
    //#region @backend
    FiredevBinaryFileBackend.prototype.saveFileNodejs = function (data, relativePath) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var destinationFilePath, buffer;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        destinationFilePath = (0, tnp_core_1.crossPlatformPath)([this.assetsPath, relativePath]);
                        console.log('UPLOADING FILE', {
                            destinationFilePath: destinationFilePath,
                            data: data
                        });
                        if (!tnp_core_1.Helpers.exists(tnp_core_1.path.dirname(destinationFilePath))) {
                            tnp_core_1.Helpers.mkdirp(tnp_core_1.path.dirname(destinationFilePath));
                        }
                        if (!tnp_core_1.Helpers.isBlob(data)) return [3 /*break*/, 2];
                        return [4 /*yield*/, tnp_core_1.Utils.binary.blobToBuffer(data)];
                    case 1:
                        buffer = _a.sent();
                        tnp_core_1.Helpers.writeFile(destinationFilePath, buffer);
                        return [3 /*break*/, 5];
                    case 2:
                        if (!(tnp_core_1._.isString(data) || tnp_core_1.Helpers.isBuffer(data))) return [3 /*break*/, 3];
                        tnp_core_1.Helpers.writeFile(destinationFilePath, data);
                        return [3 /*break*/, 5];
                    case 3: return [4 /*yield*/, new Promise(function (resolve) {
                            data.mv(destinationFilePath, function () {
                                resolve();
                            });
                        })];
                    case 4: return [2 /*return*/, _a.sent()];
                    case 5: return [2 /*return*/];
                }
            });
        });
    };
    //#endregion
    //#endregion
    //#region public methods / get file from filesystem in nodejs
    //#region @backend
    FiredevBinaryFileBackend.prototype.getFileNodejs = function (relativePath) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var destinationFilePath, buffer;
            var _this = this;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        //#region prepare proper path
                        (function () {
                            var browserPathStart = '/assets/assets-for/';
                            if (relativePath.startsWith(browserPathStart)) {
                                relativePath = relativePath.replace(/^\//, '');
                                var packageName = tnp_core_1._.first(relativePath.split('/').slice(2));
                                if (packageName === _this.project.name) {
                                    relativePath = 'src/assets/' + relativePath.split('/').slice(3).join('/');
                                }
                                else {
                                    relativePath = "".concat(tnp_config_1.config.folder.node_modules, "/") + relativePath.split('/').slice(3).join('/');
                                }
                            }
                        })();
                        (function () {
                            var browserPathStart = '/src/assets/assets-for/';
                            if (relativePath.startsWith(browserPathStart)) {
                                relativePath = relativePath.replace(/^\//, '');
                                var packageName = tnp_core_1._.first(relativePath.split('/').slice(3));
                                if (packageName === _this.project.name) {
                                    relativePath = 'src/assets/' + relativePath.split('/').slice(4).join('/');
                                }
                                else {
                                    relativePath = "".concat(tnp_config_1.config.folder.node_modules, "/") + relativePath.split('/').slice(4).join('/');
                                }
                            }
                        })();
                        destinationFilePath = (0, tnp_core_1.crossPlatformPath)([this.assetsPath, relativePath]);
                        console.log({
                            destinationFilePath: destinationFilePath,
                            'asdas': 'asdasd'
                        });
                        return [4 /*yield*/, tnp_core_2.fse.readFile(destinationFilePath)];
                    case 1:
                        buffer = _a.sent();
                        return [2 /*return*/, buffer];
                }
            });
        });
    };
    //#endregion
    //#endregion
    //#region public methods / save file in websql mode
    //#region @websql
    FiredevBinaryFileBackend.prototype.saveFileWebsql = function (file, relativePath) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var blob, _a;
            return tslib_1.__generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        if (!tnp_core_1.Helpers.isBlob(file)) return [3 /*break*/, 1];
                        _a = file;
                        return [3 /*break*/, 3];
                    case 1: return [4 /*yield*/, tnp_core_1.Utils.binary.fileToBlob(file)
                        /* */
                        /* */
                    ];
                    case 2:
                        _a = _b.sent();
                        _b.label = 3;
                    case 3:
                        blob = _a;
                        return [2 /*return*/];
                }
            });
        });
    };
    //#endregion
    //#endregion
    //#region public methods / get file from websql mode filesystem
    //#region @websql
    FiredevBinaryFileBackend.prototype.getFileWebsql = function (relativePath) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                /* */
                /* */
                /* */
                /* */
                return [2 /*return*/, void 0];
            });
        });
    };
    //#endregion
    //#endregion
    //#region public methods / get asset for (websql/nodejs) mode
    FiredevBinaryFileBackend.prototype.getAssets = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var proj, assetsListDist, assetsListBundle, readAssetsFrom, data;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        //#region websqlFunc
                        //#region @backend
                        if (tnp_core_1.Helpers.isNode) {
                            proj = this.project;
                            assetsListDist = proj.pathFor("tmp-apps-for-dist/".concat(this.project.name, "/src/assets/assets-list.json"));
                            assetsListBundle = proj.pathFor("tmp-apps-for-bundle/".concat(this.project.name, "/src/assets/assets-list.json"));
                            readAssetsFrom = tnp_core_1.Helpers.exists(assetsListDist) ? assetsListDist : assetsListBundle;
                            return [2 /*return*/, tnp_core_1.Helpers.readJson(readAssetsFrom) || []];
                        }
                        return [4 /*yield*/, (0, axios_1.default)({
                                // @ts-ignore
                                url: "".concat(urlStart, "assets/assets-list.json"),
                                method: 'GET',
                                responseType: 'json'
                            })];
                    case 1:
                        data = _a.sent();
                        return [2 /*return*/, data.data];
                }
            });
        });
    };
    //#endregion
    //#region public methods / get asset for (websql/nodejs) mode
    FiredevBinaryFileBackend.prototype.getAssetFromWebsqlMode = function (assetPath) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var data;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, (0, axios_1.default)({
                            // @ts-ignore
                            url: "".concat(urlStart).concat(assetPath),
                            method: 'GET',
                            responseType: 'blob'
                        })];
                    case 1:
                        data = _a.sent();
                        return [2 /*return*/, data.data];
                }
            });
        });
    };
    return FiredevBinaryFileBackend;
}());
exports.FiredevBinaryFileBackend = FiredevBinaryFileBackend;
//# sourceMappingURL=firedev-binary-file-backend.js.map