/// <reference types="node" />
import { Firedev } from 'firedev';
import { FiredevBinaryFile } from './firedev-binary-file';
import { Utils } from 'tnp-core';
import { FiredevDbEntity } from './firedev-db-entity';
import { FiredevBinaryFileBackend } from './backend/firedev-binary-file-backend';
import { Blob } from 'buffer';
/**
 * Isomorphic Controller for FiredevBinaryFile
 *
 * + only create here isomorphic controller methods
 * + use this.backend for any backend/db operations
 */
export declare class FiredevBinaryFileController extends Firedev.Base.Controller<FiredevBinaryFile> {
    entity: typeof FiredevBinaryFile;
    readonly backend: FiredevBinaryFileBackend;
    save(binaryData: Utils.DbBinaryFormatForBrowser, relativePathOnServer: string): Promise<void>;
    load<T = Utils.DbBinaryFormat>(relativePathOnServer: string, loadAs?: Utils.DbBinaryFormatEnum): Promise<T>;
    protected saveFile(file: File, relativePathOnServer?: string): Promise<FiredevBinaryFile>;
    protected saveBlob(blob: Blob, relativePathOnServer: string): Promise<void>;
    protected saveText(text: string, filename: string): Promise<void>;
    protected getText(relativePathOnServer: string): Promise<string>;
    protected getBlob(relativePathOnServer: string): Promise<Blob>;
    protected getFile(relativePathOnServer: string): Promise<File>;
    initExampleDbData(isWorker?: boolean): Promise<void>;
    private _getBlob;
    private saveFormData;
    getByUrl(relativePathOnServer: string): Firedev.Response<FiredevBinaryFile>;
    getAllEntities(): Firedev.Response<FiredevDbEntity[]>;
}