"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FiredevFileController = void 0;
var tslib_1 = require("tslib");
//#region imports
var firedev_1 = require("firedev");
var firedev_file_1 = require("./firedev-file");
var tnp_core_1 = require("tnp-core");
var tnp_helpers_1 = require("tnp-helpers");
//#region @backend
var FormData = require("form-data");
var pathDest = tnp_core_1.path.join(process.cwd(), 'src/assets/private/uploaded');
//#endregion
//#region @websql
var firedev_file_backend_1 = require("./backend/firedev-file-backend");
/**
 * @deprecated
 */
var FiredevFileController = exports.FiredevFileController = /** @class */ (function (_super) {
    tslib_1.__extends(FiredevFileController, _super);
    function FiredevFileController() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        //#region @websql
        _this.backend = firedev_file_backend_1.FiredevFileBackend.for(_this);
        return _this;
        //#endregion
        //#endregion
    }
    //#endregion
    //#endregion
    //#region get latest version by src
    FiredevFileController.prototype.getLatestVersion = function (src) {
        var _this = this;
        //#region @websqlFunc
        return function (req, res) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var repo, item;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        repo = this.repository;
                        src = decodeURIComponent(src);
                        return [4 /*yield*/, repo.findOne({
                                where: {
                                    src: src,
                                }
                            })];
                    case 1:
                        item = _a.sent();
                        return [2 /*return*/, (item === null || item === void 0 ? void 0 : item.version) || 0];
                }
            });
        }); };
        //#endregion
    };
    //#endregion
    //#region get blobless by src
    FiredevFileController.prototype.getBloblessBy = function (src) {
        var _this = this;
        //#region @websqlFunc
        src = decodeURIComponent(src);
        return function (req, res) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var repo, item;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        repo = this.repository;
                        return [4 /*yield*/, repo.findOne({
                                where: {
                                    src: src,
                                }
                            })];
                    case 1:
                        item = _a.sent();
                        if (item === null || item === void 0 ? void 0 : item.blob) {
                            delete item.blob;
                        }
                        return [2 /*return*/, item];
                }
            });
        }); };
        //#endregion
    };
    //#endregion
    //#region get blob only by src
    FiredevFileController.prototype.getBlobOnlyBy = function (src) {
        var _this = this;
        //#region @websqlFunc
        src = decodeURIComponent(src);
        return function (req, res) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var repo, item, blob;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        repo = this.repository;
                        return [4 /*yield*/, repo.findOne({
                                where: {
                                    src: src,
                                }
                            })];
                    case 1:
                        item = _a.sent();
                        return [4 /*yield*/, this.backend.restoreBlobWhenFileFromAsset(item)];
                    case 2:
                        item = _a.sent();
                        return [4 /*yield*/, tnp_core_1.Utils.binary.base64toBlob(item.blob)];
                    case 3:
                        blob = _a.sent();
                        return [2 /*return*/, blob];
                }
            });
        }); };
        //#endregion
    };
    //#endregion
    //#region delete by src
    FiredevFileController.prototype.deleteBy = function (src) {
        var _this = this;
        //#region @websqlFunc
        return function (req, res) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var repo, item;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        repo = this.repository;
                        return [4 /*yield*/, repo.findOne({
                                where: {
                                    src: decodeURI(src),
                                }
                            })];
                    case 1:
                        item = _a.sent();
                        // await repo.delete
                        delete item.blob;
                        return [2 /*return*/, item];
                }
            });
        }); };
        //#endregion
    };
    //#endregion
    //#region upload form data
    /**
     * in angular:
     * const formData = new FormData();
     * formData.append('myfile1.png',files[0])
     * formData.append('myfile2.png',files[1])
     *
     * files -> from evemt from input with type="file"
     *
     * @param formData
     * @returns
     */
    FiredevFileController.prototype.upload = function (formData) {
        var _this = this;
        //#region @websqlFunc
        return function (req, res) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var files, repo, file, uploadPath, fileInstance;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        //#region @backendFunc
                        // @ts-ignore
                        if (!req.files || Object.keys(req.files).length === 0) {
                            res.status(400).send('No files were uploaded.');
                            return [2 /*return*/];
                        }
                        files = tnp_core_1._.values(req.files);
                        if (!tnp_helpers_1.Helpers.exists(tnp_core_1.path.dirname(pathDest))) {
                            tnp_helpers_1.Helpers.mkdirp(tnp_core_1.path.dirname(pathDest));
                        }
                        repo = this.repository;
                        file = tnp_core_1._.first(files);
                        uploadPath = (0, tnp_core_1.crossPlatformPath)([pathDest, file.md5 + '_' + file.name]);
                        return [4 /*yield*/, repo.save(firedev_file_1.FiredevFile.from({
                                contentType: file.mimetype,
                                id: file.md5,
                                blob: file.data,
                                src: uploadPath,
                            }))];
                    case 1:
                        _a.sent();
                        return [4 /*yield*/, new Promise(function (resolve, reject) {
                                file.mv(uploadPath, function (err) {
                                    if (err) {
                                        throw err;
                                    }
                                    else {
                                        resolve(void 0);
                                    }
                                });
                            })];
                    case 2:
                        _a.sent();
                        console.log("Files uploaded: ", req['files']);
                        return [4 /*yield*/, repo.findOneOrFail({ where: { id: file.md5 } })];
                    case 3:
                        fileInstance = _a.sent();
                        delete fileInstance.blob;
                        return [2 /*return*/, fileInstance];
                }
            });
        }); };
        //#endregion
    };
    //#endregion
    //#region init example data
    //#region @websql
    FiredevFileController.prototype.initExampleDbData = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.backend.initExampleDbData()];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    tslib_1.__decorate([
        firedev_1.Firedev.Http.GET('/version/:src'),
        tslib_1.__param(0, firedev_1.Firedev.Http.Param.Path('src')),
        tslib_1.__metadata("design:type", Function),
        tslib_1.__metadata("design:paramtypes", [String]),
        tslib_1.__metadata("design:returntype", Object)
    ], FiredevFileController.prototype, "getLatestVersion", null);
    tslib_1.__decorate([
        firedev_1.Firedev.Http.GET('/blobless/:src'),
        tslib_1.__param(0, firedev_1.Firedev.Http.Param.Path('src')),
        tslib_1.__metadata("design:type", Function),
        tslib_1.__metadata("design:paramtypes", [String]),
        tslib_1.__metadata("design:returntype", Object)
    ], FiredevFileController.prototype, "getBloblessBy", null);
    tslib_1.__decorate([
        firedev_1.Firedev.Http.GET({
            overridResponseType: 'blob',
            path: '/blobonly/:src'
        }),
        tslib_1.__param(0, firedev_1.Firedev.Http.Param.Path('src')),
        tslib_1.__metadata("design:type", Function),
        tslib_1.__metadata("design:paramtypes", [String]),
        tslib_1.__metadata("design:returntype", Object)
    ], FiredevFileController.prototype, "getBlobOnlyBy", null);
    tslib_1.__decorate([
        firedev_1.Firedev.Http.DELETE({
            overridResponseType: 'blob',
            path: '/blobonly/:src'
        }),
        tslib_1.__param(0, firedev_1.Firedev.Http.Param.Path('src')),
        tslib_1.__metadata("design:type", Function),
        tslib_1.__metadata("design:paramtypes", [String]),
        tslib_1.__metadata("design:returntype", Object)
    ], FiredevFileController.prototype, "deleteBy", null);
    tslib_1.__decorate([
        firedev_1.Firedev.Http.POST({ overrideContentType: 'multipart/form-data' }),
        tslib_1.__param(0, firedev_1.Firedev.Http.Param.Body()),
        tslib_1.__metadata("design:type", Function),
        tslib_1.__metadata("design:paramtypes", [FormData]),
        tslib_1.__metadata("design:returntype", Object)
    ], FiredevFileController.prototype, "upload", null);
    FiredevFileController = tslib_1.__decorate([
        firedev_1.Firedev.Controller({
            //#region controller config
            className: 'FiredevFileController',
            entity: firedev_file_1.FiredevFile
            //#endregion
        })
    ], FiredevFileController);
    return FiredevFileController;
}(firedev_1.Firedev.Base.Controller));
//# sourceMappingURL=firedev-file.controller.js.map